/*******************************************************************************
 * Copyright 2012 University of Southern California
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * This code was developed by the Information Integration Group at 
 * the Information Sciences Institute of the University of Southern California.  
 * For more information, publications, and related projects, 
 * please see: http://www.isi.edu/integration
 ******************************************************************************/

package mf.classify;

import java.io.BufferedReader;
import java.io.FileReader;
import java.util.ArrayList;

public class Index {
	
	/**
	 * @param indexFile
	 * @param imageNames
	 * @param imageFeatures
	 * @throws Exception
	 * This static method reads in an indexFile that was generated using BuildIndex.
	 * It populates the first list - imageNames, with the names of the images, in the same order as they exist in the indexFile.
	 * It populates the second list - imageFeatures, with the features of the images, again, in the same order as they exist in the indexFile.
	 */
	public static void load(String indexFile, ArrayList<String> imageNames, ArrayList<int[]> imageFeatures) throws Exception {
		BufferedReader br;
		String line ;
		
		br = new BufferedReader(new FileReader(indexFile)) ;
		imageNames.clear() ;
		imageFeatures.clear() ;
		while((line=br.readLine()) != null) {
			String[] token ;
			int[] waterfillingFeatures;
			waterfillingFeatures = new int[24] ;
			token = line.split("\\s") ;
			imageNames.add(token[0]) ;
			for(int i=0;i<24;i++) {
				waterfillingFeatures[i] = Integer.parseInt(token[i+1]) ;
			}
			imageFeatures.add(waterfillingFeatures) ;
		}
		br.close() ;
	}
	
}
