/*******************************************************************************
 * Copyright 2012 University of Southern California
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * This code was developed by the Information Integration Group at 
 * the Information Sciences Institute of the University of Southern California.  
 * For more information, publications, and related projects, 
 * please see: http://www.isi.edu/integration
 ******************************************************************************/

package mf.classify;

import java.io.BufferedReader;
import java.io.FileReader;
import java.util.ArrayList;

import mf.common.Constants;


public class State {
	
	static ArrayList<String> mapsList ;
	static ArrayList<String> nonmapsList ;
	static boolean initialized = false ;


	/**
	 * @throws Exception
	 * This method populates two ArrayLists with the names of the images that are maps and names of images that are non-maps.
	 * These lists are later used by other methods of this class to know the type (map vs non-map) of an image given its name.
	 * Therefore, it is important to keep the names of maps and non-maps mutually exclusive.
	 * We do it by naming all images serially irrespective of whether the image is a map or non-map. 
	 */
	static void init() throws Exception {
		String filename ;
		BufferedReader br  ;
		if(initialized) {
			return ;
		}
		mapsList = new ArrayList<String>() ;
		nonmapsList = new ArrayList<String>() ;
		br = new BufferedReader(new FileReader(Constants.mapsListFile)) ;
		while((filename = br.readLine()) != null) { 
			mapsList.add(filename) ;
		}
		br.close() ;
		br = new BufferedReader(new FileReader(Constants.nonmapsListFile)) ;
		while((filename = br.readLine()) != null) { 
			nonmapsList.add(filename) ;
		}
		br.close() ;
		initialized = true;
	}

	
	/**
	 * @param imageName Name of the image whose type is to be known.
	 * @return A constant indicating whether the image is a map or non-map.
	 * @throws Exception
	 * This method invokes init() to make sure the lists are populated.
	 * It then checks which of the two lists contains the name given.
	 */
	public static int label(String imageName) throws Exception {
		init() ;
		if(mapsList.contains(imageName)) {
			return Constants.MAP ;
		}
		else if(nonmapsList.contains(imageName)) {
			return Constants.NONMAP ;
		}
		else {
			throw new Exception("imageName not found in maps or nonmaps list. Throwing error") ; 
		}
	}
	
	
}

