/*******************************************************************************
 * Copyright 2012 University of Southern California
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * This code was developed by the Information Integration Group at 
 * the Information Sciences Institute of the University of Southern California.  
 * For more information, publications, and related projects, 
 * please see: http://www.isi.edu/integration
 ******************************************************************************/

package mf.runnable ;

import java.awt.image.BufferedImage;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;

import javax.imageio.ImageIO;

import mf.ftrs.WaterFilling;

public class BuildIndex {
	
	
	private static final String cannyDir = "/data/mf/set/";
	private static final String indexFile = "/data/mf/index.txt" ;
	
	/**
	 * @param args
	 * @throws Exception
	 * Run this main method to build an index file.
	 * The index file has one line per image, the line having the following format:
	 * <NameOfImageFile> <24 dimension Feature Vector (space separated 24 integers)>
	 */
	public static void main(String[] args) throws Exception {
		build(cannyDir, indexFile) ;
	}
	
	/**
	 * @param cannyDir The directory that contains the Canny image files
	 * @param indexFile The target text file to which the generated index should be written
	 * @throws Exception
	 */
	static void build(String cannyDir, String indexFile) throws Exception {
		BufferedWriter bw ;
		File dir ;
		File[] allFiles ;
		
		bw = new BufferedWriter(new FileWriter(indexFile)) ;
		dir = new File(cannyDir) ;
		if(!dir.exists())
			throw new Exception("Canny directory not found") ;
		allFiles = dir.listFiles() ;
		for(int i=0;i<allFiles.length;i++) {
			BufferedImage bimg ;
			String fileName ;
			WaterFilling wf ;
			String s ;
			
			fileName = allFiles[i].getName() ;
			if(fileName.length() < 4 || !fileName.substring(fileName.length() - 3).equalsIgnoreCase("gif")) {
				// assuming that the file names end with .gif
				continue ;
			}
			
			System.out.println("Extracting waterfilling features for image: " + fileName);
			
			bimg = ImageIO.read(allFiles[i]) ;
			wf = new WaterFilling(bimg) ;
			s = fileName ;
			for(int j=0;j<8;j++) {
				s+=" " ;
				s+=wf.FTH[j][0] ;
			}
			for(int j=0;j<8;j++) {
				s+=" " ;
				s+=wf.FCH[j][0] ;
			}
			for(int j=0;j<8;j++) {
				s+=" " ;
				s+=wf.WAH[j] ;
			}				             
			bw.write(s+"\n") ;
		}
		bw.close() ;
	}
	
}

		
			
		
		
		