/*******************************************************************************
 * Copyright 2012 University of Southern California
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * This code was developed by the Information Integration Group at 
 * the Information Sciences Institute of the University of Southern California.  
 * For more information, publications, and related projects, 
 * please see: http://www.isi.edu/integration
 ******************************************************************************/

package mf.runnable;

import java.awt.image.BufferedImage;
import java.io.File;
import java.util.ArrayList;

import javax.imageio.ImageIO;

import mf.classify.Index;
import mf.classify.KNN;
import mf.classify.State;
import mf.common.Util;
import mf.ftrs.WaterFilling;

public class Classification {
	
	
	static final String testDir = "/data/mf/set/" ;
	static final String indexFile = "/data/mf/index.txt";
	
	
	/**
	 * @param args
	 * @throws Exception
	 * This method predicts the class of each images in the testDir using the index.
	 * It then compares the prediction with the ground truth and
	 * at the end prints the over all accuracy of prediction.
	 */
	public static void main(String[] args) throws Exception {
		File[] imageList ;
		ArrayList<String> name ;
		ArrayList<int[]> repos ;
		int correct, wrong, count;
		
		name = new ArrayList<String>() ;
		repos = new ArrayList<int[]>() ;
		correct = wrong = count = 0 ;
		Index.load(indexFile, name, repos) ;
		imageList = new File(testDir).listFiles() ;
		
		for(File image : imageList) {
			String imagename ; 
			WaterFilling wf ;
			BufferedImage bimg ;
			
			imagename = image.getName() ;
			if(imagename.length() < 4 || !imagename.substring(imagename.length() - 3).equalsIgnoreCase("gif")) {
				// assuming that the file names end with .gif
				continue ;
			}
			count++;
			
			System.out.println("Classifying image: " + imagename);
			
			bimg = ImageIO.read(image) ;
			wf = new WaterFilling(bimg) ;
			if(State.label(imagename) == KNN.predictType(wf, name, repos))
				correct++ ;
			else
				wrong++ ;
		}
		
		Util.prn("Correctly classified = " + correct) ;
		Util.prn("Incorrectly classified = " + wrong) ;
		
		
		
		
		
	}
}